==> kdevelop_4.6.0.orig.tar.xz: kdevelop-4.6.0/projectmanagers/cmake/kdevcmakemanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=CMake Project Manager
Name[bs]=Cmake menadžer projekta
Name[ca]=Gestor de projectes CMake
Name[ca@valencia]=Gestor de projectes CMake
Name[cs]=Správce projektů CMake
Name[da]=CMake-projekthåndtering
Name[de]=CMake-Projektverwaltung
Name[el]=Διαχειριστής έργου CMake
Name[en_GB]=CMake Project Manager
Name[es]=Gestor de proyectos CMake
Name[et]=CMake'i projektihaldur
Name[fi]=CMake-projektinhallinta
Name[fr]=Gestionnaire de projets CMake
Name[gl]=Xestor de proxectos CMake
Name[hu]=CMake projektkezelő
Name[it]=Gestore progetto CMake
Name[ja]=CMake プロジェクトマネージャ
Name[kk]=CMake жоба менеджері
Name[km]=កម្មវិធី​គម្រោង CMake
Name[nb]=CMake prosjekstyrer
Name[nds]=CMake-Projektpleger
Name[nl]=CMake-projectbeheerder
Name[pl]=Menadżer projektów CMake
Name[pt]=Gestor de Projectos do CMake
Name[pt_BR]=Gerenciador de Projeto CMake
Name[ru]=Управление проектами CMake
Name[sk]=Projektový manažér CMake
Name[sl]=Upravljalnik projekta CMake
Name[sv]=CMake-projekthantering
Name[tr]=CMake Proje Yönetici
Name[ug]=CMake قۇرۇلۇش باشقۇرغۇچ
Name[uk]=Керування проектами CMake
Name[x-test]=xxCMake Project Managerxx
Name[zh_CN]=CMake 工程管理器
Name[zh_TW]=CMake 專案管理員
GenericName=Project Manager
GenericName[bs]=Rukovodilac projekta
GenericName[ca]=Gestor de projectes
GenericName[ca@valencia]=Gestor de projectes
GenericName[cs]=Správce projektů
GenericName[da]=Projekthåndtering
GenericName[de]=Projektverwaltung
GenericName[el]=Διαχειριστής έργου
GenericName[en_GB]=Project Manager
GenericName[eo]=Projektadministrilo
GenericName[es]=Gestor de proyectos
GenericName[et]=Projektihaldur
GenericName[fi]=Projektihallinta
GenericName[fr]=Gestionnaire de projets
GenericName[ga]=Bainisteoir Tionscadail
GenericName[gl]=Xestor de proxectos
GenericName[hu]=Projektkezelő
GenericName[it]=Gestore progetto
GenericName[ja]=プロジェクトマネージャ
GenericName[kk]=Жоба менеджері
GenericName[km]=កម្មវិធី​គ្រប់គ្រង​គម្រោង
GenericName[nb]=Prosjektbehandler
GenericName[nds]=Projektpleger
GenericName[nl]=Projectbeheerder
GenericName[nn]=Prosjekthandsamar
GenericName[pl]=Menadżer projektu
GenericName[pt]=Gestor de Projectos
GenericName[pt_BR]=Gerenciador de Projetos
GenericName[ru]=Управление проектами
GenericName[sk]=Správca projektu
GenericName[sl]=Upravljalnik projektov
GenericName[sv]=Projekthantering
GenericName[tr]=Proje Yönetici
GenericName[ug]=قۇرۇلۇش باشقۇرغۇچ
GenericName[uk]=Керування проектами
GenericName[x-test]=xxProject Managerxx
GenericName[zh_CN]=工程管理器
GenericName[zh_TW]=專案管理員
Comment=Allows KDevelop to manage CMake-based projects
Comment[bs]=Dopušta da KDevelop upravlja CMake-baziranim projektima
Comment[ca]=Permet que el KDevelop gestioni projectes basats en CMake
Comment[ca@valencia]=Permet que el KDevelop gestione projectes basats en CMake
Comment[cs]=Umožňuje KDevelop spravovat projekty založené na CMake
Comment[da]=Lader KDevelop håndtere CMake-baserede projekter
Comment[de]=Erlaubt das Verwalten CMake-basierter Projekte mit KDevelop
Comment[el]=Επιτρέπει στο KDevelop τη διαχείριση έργων με βάση το CMake
Comment[en_GB]=Allows KDevelop to manage CMake-based projects
Comment[es]=Permite que KDevelop gestione proyectos basados en CMake
Comment[et]=Võimaldab KDevelopil hallata CMake'i põhiseid projekte
Comment[fi]=Sallii KDevelop-ohjelman hallinnoida CMake-perustaisia projekteja
Comment[fr]=Permet à KDevelop de gérer des projets utilisant CMake
Comment[ga]=Ceadaigh do KDevelop tionscadail CMake a bhainistiú
Comment[gl]=Permítelle a KDevelop xestionar proxectos baseados en CMake
Comment[hu]=Lehetővé teszi a KDevelop számára a CMake alapú projektek kezelését
Comment[it]=Permette a KDevelop di gestire i progetti basati su CMake
Comment[kk]=KDevelop-та CMake жобаларын басқару мүмкіндігі
Comment[nb]=Gjør at KDevelop kan håndtere prosjekter basert på CMake
Comment[nds]=Projekten mit KDevelop plegen, de op CMake opbuut
Comment[nl]=Staat KDevelop toe om op CMake gebaseerde projecten te beheren
Comment[pl]=Pozwala KDevelop na zarządzanie projektami opartymi o CMake
Comment[pt]=Permite ao KDevelop gerir os projectos baseados no CMake
Comment[pt_BR]=Permite ao KDevelop gerenciar projetos baseados em CMake
Comment[ru]=Позволяет управлять проектами на базе CMake в KDevelop
Comment[sk]=Povolí KDevelopu spravovať projekty založené na CMake
Comment[sl]=Omogoča, da KDevelop upravlja s projekti temelječimi na CMake
Comment[sv]=Låter KDevelop hantera CMake-baserade projekt
Comment[tr]=KDevelop uygulamasının CMake temelli projeleri yönetmesine izin verir
Comment[ug]=KDevelop نىڭ CMake ئاساسىدىكى قۇرۇلۇشلارنى باشقۇرۇشىغا ئىجازەت
Comment[uk]=Надає змогу KDevelop керувати заснованими на CMake проектами
Comment[x-test]=xxAllows KDevelop to manage CMake-based projectsxx
Comment[zh_CN]=允许 KDevelop 管理基于 CMake 的工程
Comment[zh_TW]=允許 KDevelop 管理 CMake-based 專案
Icon=cmake
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcmakemanager
X-KDE-PluginInfo-Author=Matt Rogers
X-KDE-PluginInfo-Email=mattr@kde.org
X-KDE-PluginInfo-Name=KDevCMakeManager
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Language=CMake
X-KDevelop-Interfaces=org.kdevelop.IBuildSystemManager,org.kdevelop.IProjectFileManager,ILanguageSupport
X-KDevelop-SupportedMimeTypes=text/x-cmake
X-KDevelop-Mode=GUI
X-KDevelop-ProjectFilesFilter=CMakeLists.txt
X-KDevelop-ProjectFilesFilterDescription=CMake Project Files
X-KDevelop-LoadMode=AlwaysOn

==> kdevelop-4.6.90.tar.xz: kdevelop-4.6.90/projectmanagers/cmake/kdevcmakemanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=CMake Project Manager
Name[bs]=Cmake menadžer projekta
Name[ca]=Gestor de projectes CMake
Name[ca@valencia]=Gestor de projectes CMake
Name[cs]=Správce projektů CMake
Name[da]=CMake-projekthåndtering
Name[de]=CMake-Projektverwaltung
Name[el]=Διαχειριστής έργου CMake
Name[en_GB]=CMake Project Manager
Name[es]=Gestor de proyectos CMake
Name[et]=CMake'i projektihaldur
Name[fi]=CMake-projektinhallinta
Name[fr]=Gestionnaire de projets CMake
Name[gl]=Xestor de proxectos CMake
Name[hu]=CMake projektkezelő
Name[it]=Gestore progetto CMake
Name[ja]=CMake プロジェクトマネージャ
Name[kk]=CMake жоба менеджері
Name[km]=កម្មវិធី​គម្រោង CMake
Name[nb]=CMake prosjekstyrer
Name[nds]=CMake-Projektpleger
Name[nl]=CMake-projectbeheerder
Name[pl]=Zarządca projektów CMake
Name[pt]=Gestor de Projectos do CMake
Name[pt_BR]=Gerenciador de Projeto CMake
Name[ru]=Управление проектами CMake
Name[sk]=Projektový manažér CMake
Name[sl]=Upravljalnik projekta CMake
Name[sv]=CMake-projekthantering
Name[tr]=CMake Proje Yönetici
Name[ug]=CMake قۇرۇلۇش باشقۇرغۇچ
Name[uk]=Керування проектами CMake
Name[x-test]=xxCMake Project Managerxx
Name[zh_CN]=CMake 工程管理器
Name[zh_TW]=CMake 專案管理員
GenericName=Project Manager
GenericName[bs]=Rukovodilac projekta
GenericName[ca]=Gestor de projectes
GenericName[ca@valencia]=Gestor de projectes
GenericName[cs]=Správce projektů
GenericName[da]=Projekthåndtering
GenericName[de]=Projektverwaltung
GenericName[el]=Διαχειριστής έργου
GenericName[en_GB]=Project Manager
GenericName[eo]=Projektadministrilo
GenericName[es]=Gestor de proyectos
GenericName[et]=Projektihaldur
GenericName[fi]=Projektihallinta
GenericName[fr]=Gestionnaire de projets
GenericName[ga]=Bainisteoir Tionscadail
GenericName[gl]=Xestor de proxectos
GenericName[hu]=Projektkezelő
GenericName[it]=Gestore progetto
GenericName[ja]=プロジェクトマネージャ
GenericName[kk]=Жоба менеджері
GenericName[km]=កម្មវិធី​គ្រប់គ្រង​គម្រោង
GenericName[nb]=Prosjektbehandler
GenericName[nds]=Projektpleger
GenericName[nl]=Projectbeheerder
GenericName[nn]=Prosjekthandsamar
GenericName[pl]=Zarządca projektu
GenericName[pt]=Gestor de Projectos
GenericName[pt_BR]=Gerenciador de Projetos
GenericName[ru]=Управление проектами
GenericName[sk]=Správca projektu
GenericName[sl]=Upravljalnik projektov
GenericName[sv]=Projekthantering
GenericName[tr]=Proje Yönetici
GenericName[ug]=قۇرۇلۇش باشقۇرغۇچ
GenericName[uk]=Керування проектами
GenericName[x-test]=xxProject Managerxx
GenericName[zh_CN]=工程管理器
GenericName[zh_TW]=專案管理員
Comment=Allows KDevelop to manage CMake-based projects
Comment[bs]=Dopušta da KDevelop upravlja CMake-baziranim projektima
Comment[ca]=Permet que el KDevelop gestioni projectes basats en CMake
Comment[ca@valencia]=Permet que el KDevelop gestione projectes basats en CMake
Comment[cs]=Umožňuje KDevelop spravovat projekty založené na CMake
Comment[da]=Lader KDevelop håndtere CMake-baserede projekter
Comment[de]=Erlaubt das Verwalten CMake-basierter Projekte mit KDevelop
Comment[el]=Επιτρέπει στο KDevelop τη διαχείριση έργων με βάση το CMake
Comment[en_GB]=Allows KDevelop to manage CMake-based projects
Comment[es]=Permite que KDevelop gestione proyectos basados en CMake
Comment[et]=Võimaldab KDevelopil hallata CMake'i põhiseid projekte
Comment[fi]=Sallii KDevelop-ohjelman hallinnoida CMake-perustaisia projekteja
Comment[fr]=Permet à KDevelop de gérer des projets utilisant CMake
Comment[ga]=Ceadaigh do KDevelop tionscadail CMake a bhainistiú
Comment[gl]=Permítelle a KDevelop xestionar proxectos baseados en CMake
Comment[hu]=Lehetővé teszi a KDevelop számára a CMake alapú projektek kezelését
Comment[it]=Permette a KDevelop di gestire i progetti basati su CMake
Comment[kk]=KDevelop-та CMake жобаларын басқару мүмкіндігі
Comment[nb]=Gjør at KDevelop kan håndtere prosjekter basert på CMake
Comment[nds]=Projekten mit KDevelop plegen, de op CMake opbuut
Comment[nl]=Staat KDevelop toe om op CMake gebaseerde projecten te beheren
Comment[pl]=Pozwala KDevelop na zarządzanie projektami opartymi o CMake
Comment[pt]=Permite ao KDevelop gerir os projectos baseados no CMake
Comment[pt_BR]=Permite ao KDevelop gerenciar projetos baseados em CMake
Comment[ru]=Позволяет управлять проектами на базе CMake в KDevelop
Comment[sk]=Povolí KDevelopu spravovať projekty založené na CMake
Comment[sl]=Omogoča, da KDevelop upravlja s projekti temelječimi na CMake
Comment[sv]=Låter KDevelop hantera CMake-baserade projekt
Comment[tr]=KDevelop uygulamasının CMake temelli projeleri yönetmesine izin verir
Comment[ug]=KDevelop نىڭ CMake ئاساسىدىكى قۇرۇلۇشلارنى باشقۇرۇشىغا ئىجازەت
Comment[uk]=Надає змогу KDevelop керувати заснованими на CMake проектами
Comment[x-test]=xxAllows KDevelop to manage CMake-based projectsxx
Comment[zh_CN]=允许 KDevelop 管理基于 CMake 的工程
Comment[zh_TW]=允許 KDevelop 管理 CMake-based 專案
Icon=cmake
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcmakemanager
X-KDE-PluginInfo-Author=Matt Rogers
X-KDE-PluginInfo-Email=mattr@kde.org
X-KDE-PluginInfo-Name=KDevCMakeManager
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Language=CMake
X-KDevelop-Interfaces=org.kdevelop.IBuildSystemManager,org.kdevelop.IProjectFileManager,ILanguageSupport
X-KDevelop-SupportedMimeTypes=text/x-cmake
X-KDevelop-Mode=GUI
X-KDevelop-ProjectFilesFilter=CMakeLists.txt
X-KDevelop-ProjectFilesFilterDescription=CMake Project Files
X-KDevelop-LoadMode=AlwaysOn
